/*
 * The contents of this file are subject to the terms
 * of the Common Development and Distribution License
 * (the "License").  You may not use this file except
 * in compliance with the License.
 *
 * You can obtain a copy of the license at
 * https://jwsdp.dev.java.net/CDDLv1.0.html
 * See the License for the specific language governing
 * permissions and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL
 * HEADER in each file and include the License file at
 * https://jwsdp.dev.java.net/CDDLv1.0.html  If applicable,
 * add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your
 * own identifying information: Portions Copyright [yyyy]
 * [name of copyright owner]
 */
/*
 * Copyright (c) 2006 Sun Microsystems, Inc.
 * All rights reserved.
 */
package WsSecurity11Sign_XS;

import java.io.*;

import junit.framework.Assert;
import org.netbeans.junit.NbTestCase;
import org.netbeans.junit.NbTest;
import org.netbeans.junit.NbTestSuite;

public class WsSecurity11Sign_XSTest extends NbTestCase {
    
    String current_dir = System.getProperty("current.dir");
    String testName = null;
    String fileSeparator = null;
    String runOutputFilePath = null;

    public WsSecurity11Sign_XSTest(String testName) {
        super(testName);
    }

    public static NbTest suite() {
        NbTestSuite suite = new NbTestSuite();
        
        if(System.getProperty("s2s").equals("true") && System.getProperty("WsSecurity11Sign-XS-s2s").equals("true")) {
            suite.addTest(new WsSecurity11Sign_XSTest("testInteropScenario_s2s_WsSecurity11Sign-XS")); 
        }
        
        suite.setName("Interop scenario WsSecurity11Sign-XS");
        return suite;
    }

    public void makeViewableFromTestReport() {          
            /* Read log files in test log directory and put them in test workdir to be accessible from test report*/
            try {
                File workDir = getWorkDir();
                String testLogDir = current_dir + fileSeparator + "WsSecurity11Sign-XS" + fileSeparator + "logs";
                System.out.println("testLogDir : " + testLogDir);
                File dir = new File(testLogDir);
                System.out.println("Getting test log dir path : " + dir.getName());
                File[] logFiles = dir.listFiles();
                System.out.println("Num of files in test log dir = " + logFiles.length);
                for(int k=0; k<logFiles.length; k++) {
                    if(logFiles[k].isFile()) {
                        System.out.println("At log file : " + logFiles[k].getName());
                        //(new File(workDir,logFiles[k].getName()));
                        FileReader fIn = new FileReader(new File(testLogDir+fileSeparator+logFiles[k].getName()));
                        FileWriter fOut = new FileWriter(new File(workDir ,logFiles[k].getName()));
                        System.out.println("before file copy");
                        int c = 0;
                        while((c = fIn.read()) != -1) {
                            fOut.write(c);
                        }
                        fIn.close();
                        fOut.close();
                        System.out.println("Done copying");
                    }
                }
            } catch (Exception fileOprnEx) {
                System.out.println("Error copying files to test work directory");
                fileOprnEx.printStackTrace();
            }
    }
    
    protected void setUp() {
        current_dir = System.getProperty("current.dir");
        testName = System.getProperty("ant.project.name");
        fileSeparator = System.getProperty("file.separator");
        runOutputFilePath = current_dir + fileSeparator + "WsSecurity11Sign-XS" 
                + fileSeparator + "logs" 
                + fileSeparator + "WsSecurity11Sign-XS" + "-s2s-status.txt";
        makeViewableFromTestReport();      
    }

    protected void tearDown() {

    }

    public static void main(String[] args) {

        junit.textui.TestRunner.run(suite());
    }

    
    public void testInteropScenario_s2s_WsSecurity11Sign_XS () {
        BufferedReader in = null;
        try {
            String current_dir = System.getProperty("current.dir");
            String testName = System.getProperty("ant.project.name");
            String fileSeparator = System.getProperty("file.separator");
            String runOutputFilePath = current_dir + fileSeparator + "WsSecurity11Sign-XS" 
                + fileSeparator + "logs" 
                + fileSeparator + "WsSecurity11Sign-XS" + "-s2s-status.txt";
            try {
                in = new BufferedReader(new FileReader(new File(runOutputFilePath)));
            } catch (IOException ioEx) {
                fail(ioEx.getMessage());
                return;
            }
            String status = in.readLine();
            if(status != null){
            	if(status.equals("PASSED")) 
                    assertTrue(true);
            	else{
		    String exceptionstring = " ";
		    while((status = in.readLine()) != null){
			exceptionstring += status;
		    }
		    fail(exceptionstring);
		}
		in.close();
            }
            else{
		in.close();
                fail("Error might be due to some configuration issues. Hence, configuration/property files need to be seen.");
            }

        } catch (Exception ex) {
            ex.printStackTrace();
            fail("Error might be due to some configuration issues. Hence, configuration/property files need to be seen.");
        }
    }
    
}
